<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-page-header @back="goBack" :content="this.$route.query.name">
      </el-page-header>
    </div>
    <div class="bbsl-table-content">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-form v-model="queryParam" :inline="true">
          <el-row :gutter="10">
            <el-col :span="10">
              <el-form-item label="告警时间">
                <el-date-picker
                  v-model="querys[0].value"
                  type="datetimerange"
                  style="width: 100%"
                  value-format="yyyy-MM-dd HH:mm:ss"
                  range-separator="至"
                  start-placeholder="开始日期"
                  end-placeholder="结束日期"
                >
                </el-date-picker>
              </el-form-item>
            </el-col>
            <el-col :span="6">
              <el-form-item>
                <el-button
                  type="primary"
                  icon="el-icon-search"
                  @click="handleSearch"
                >搜索
                </el-button
                >
                <el-button icon="el-icon-refresh" @click="handleReset"
                >重置
                </el-button
                >
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <el-table
        border
        size="mini"
        v-loading="loading"
        ref="multipleSelection"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @selection-change="handleSelectionChange"
      >
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column
          fixed
          type="index"
          width="55"
          label="序号"
        ></el-table-column>
        <el-table-column
          sortable
          prop="deviceTypeName"
          label="告警设备类型"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          sortable
          prop="warnName"
          label="告警名称"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          sortable
          prop="warnReason"
          label="告警缘由"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          min-width="100"
          sortable
          prop="warnTime"
          label="告警时间"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          sortable
          min-width="100"
          prop="warnTypeName"
          label="告警类型"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          min-width="90"
          sortable
          prop="handleStatus"
          label="处理状态"
          show-overflow-tooltip
        >
          <template slot-scope="scope">
            <span
              :style="{
                color:
                  scope.row.handleStatus == 0
                    ? 'red'
                    : scope.row.handleStatus == 1
                    ? 'green'
                    : '',
              }"
            >{{
                scope.row.handleStatus == 0
                  ? '未处理'
                  : scope.row.handleStatus == 1
                  ? '已处理'
                  : ''
              }}</span
            >
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
        align="right"
        background
        class="bbsl-pagination"
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
      ></el-pagination>
    </div>
  </div>
</template>
<script>
import {TableMixin} from '@/mixins/tableMixin'
import EquipmentMaintain from '@/api/device/EquipmentMaintain.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'MaintainDetails',
  components: {},
  mixins: [TableMixin],
  data() {
    return {
      total: 0,
      warnTypeList: [],
      parameters: {}, //接收路由参数
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'warn.WARN_TIME_',
          relation: 'AND',
          value: ''
        }
      ]
    }
  },
  created() {
    this.deviceTypeList = dictUtils.getDictItemsFromCache('gjsblx')
    this.warnTypeList = dictUtils.getDictItemsFromCache('gjlx')
    this.parameters = this.$route.query
    console.log(this.parameters)
  },
  methods: {
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam = {
        groupRelation: 'AND',
        groupTree: {},
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'warn.DEVICE_CODE_',
            relation: 'AND',
            value: this.parameters.code
          }
        ],
        sorter: [
          {
            direction: 'DESC',
            property: 'warn.WARN_TIME_'
          }
        ]
      }
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      EquipmentMaintain.getwarnInfo(this.queryParam, (res) => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.tableData.forEach((item) => {
          this.warnTypeList.forEach((val) => {
            if (item.warnType == val.value) {
              item['warnTypeName'] = val.name
            }
          })
          this.deviceTypeList.forEach((val) => {
            if (item.deviceType == val.value) {
              item['deviceTypeName'] = val.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    goBack() {
      this.$router.go(-1)
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.loadData(1)
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
